<?php

namespace Drupal\sibs_api\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * The audits form.
 */
final class AuditsForm extends FormBase {

  /**
   * The requestStack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * {@inheritdoc}
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'audits_filter';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $request = $this->requestStack->getCurrentRequest()->query->all();

    $form['transaction_type'] = [
      '#type' => 'select',
      '#title' => $this->t('Transaction Type'),
      '#options' => [
        '' => $this->t('All'),
        'prepareCheckout' => $this->t('prepareCheckout'),
        'getpaymentStatus' => $this->t('getpaymentStatus'),
        'webhook' => $this->t('webhook'),
      ],
      '#default_value' => (!empty($request['transaction_type'])) ? $request['transaction_type'] : '',
    ];

    $form['transaction_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Transaction ID'),
      '#default_value' => (!empty($request['transaction_id'])) ? $request['transaction_id'] : '',
    ];

    $form['description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => (!empty($request['description'])) ? $request['description'] : '',
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Search', [], ['context' => 'action']),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $query = $this->requestStack->getCurrentRequest()->query->all();

    if (isset($query['page'])) {
      unset($query['page']);
    }

    unset($query['transaction_type']);
    if (!empty($values['transaction_type'])) {
      $query['transaction_type'] = $values['transaction_type'];
    }

    unset($query['transaction_id']);
    if (!empty($values['transaction_id'])) {
      $query['transaction_id'] = $values['transaction_id'];
    }

    unset($query['description']);
    if (!empty($values['description'])) {
      $query['description'] = $values['description'];
    }

    $form_state->setRedirect('sibs_api.audits', [], ['query' => $query]);
  }

}
